nikola.plugins.template package
===============================

Submodules
----------

nikola.plugins.template.jinja module
------------------------------------

.. automodule:: nikola.plugins.template.jinja
    :members:
    :undoc-members:
    :show-inheritance:

nikola.plugins.template.mako module
-----------------------------------

.. automodule:: nikola.plugins.template.mako
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nikola.plugins.template
    :members:
    :undoc-members:
    :show-inheritance:
